@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Math::Shape::Line;
-$Math::Shape::Line::VERSION = '0.05';
+$Math::Shape::Line::VERSION = '0.06';
 use 5.008;
 use Carp;
 use Math::Shape::Vector;
@@ -31,6 +31,26 @@ sub is_equivalent
 }
 
 
+sub on_one_side
+{
+    croak 'project not called with argument of type Math::Shape::Line' unless $_[1]->isa('Math::Shape::LineSegment');
+    my ($self, $segment) = @_;
+
+    my $vector_d1 = Math::Shape::Vector->new($segment->{start}->{x}, $segment->{start}->{y});
+    $vector_d1->subtract_vector($self->{base});
+
+    my $vector_d2 = Math::Shape::Vector->new($segment->{end}->{x}, $segment->{end}->{y});
+    $vector_d2->subtract_vector($self->{base});
+
+    my $vector_n = Math::Shape::Vector->new($self->{direction}->{x}, $self->{direction}->{y});
+    $vector_n->rotate_90;
+
+    $vector_n->dot_product($vector_d1)
+    * $vector_n->dot_product($vector_d2) > 0 ? 1 : 0;
+}
+
+
+
 sub collides
 {
     croak 'must pass a line object' unless $_[1]->isa('Math::Shape::Line');
@@ -58,7 +78,7 @@ Math::Shape::Line - a 2d vector line object - an infinite 2d line
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 METHODS
 
@@ -72,6 +92,10 @@ Constructor, requires 4 values: the x,y values for the base and direction vector
 
 Boolean method returns 1 if the line is equivalent to another line object. Requires a Math::Shape::Line object as an argument.
 
+=head2 one_one_side
+
+Boolean method that returns 1 if both points of a line segment object are on the same side of the line. Requires a L<Math::Shape::LineSegment> object as an argument.
+
 =head2 collides
 
 Boolean method that returns 1 if the line collides with another line or 0 if not. Requires a Math::Shape::Line object as an argument
